@@ -893,16 +893,24 @@ class Askdata(SignUp):
         response.raise_for_status()
         result = response.json()["result"]
 
-        #print("{} from the dataset: {} / {}".format(self.extract_fields(result[0]["attachment"]["body"][0]["details"]["columns"]), workspace, result[0]["attachment"]["body"][0]["details"]["datasetName"]))
-        display(HTML("<p>{} from the dataset: {} / {}</p>".format(self.extract_fields(result[0]["attachment"]["body"][0]["details"]["columns"]), workspace, result[0]["attachment"]["body"][0]["details"]["datasetName"])))
-        if(len(result[0]["attachment"]["body"])>1):
-            print("Filtered by: {}".format(result[0]["attachment"]["body"][1]["details"]["text"]))
-        if(len(result)>1):
-            print("{} Alternatives:".format(len(result)-1))
-            for r in result[1:]:
-                print("     {} from the dataset: {} / {}".format(self.extract_fields(r["attachment"]["body"][0]["details"]["columns"]), workspace, r["attachment"]["body"][0]["details"]["datasetName"]))
+        if(dataset_id!=''):
+            filtered_result = []
+            for r in result:
+                if(r["attachment"]["body"][0]["details"]["datasetId"]==dataset_id):
+                    filtered_result.append(r)
+        else:
+            filtered_result = result
 
-        df = pd.DataFrame(data=result[0]["attachment"]["body"][0]["details"]["rows"], columns=result[0]["attachment"]["body"][0]["details"]["columns"])
+        #print("{} from the dataset: {} / {}".format(self.extract_fields(result[0]["attachment"]["body"][0]["details"]["columns"]), workspace, result[0]["attachment"]["body"][0]["details"]["datasetName"]))
+        display(HTML("<p>{} from the dataset: {} / {}</p>".format(self.extract_fields(filtered_result[0]["attachment"]["body"][0]["details"]["columns"]), workspace, filtered_result[0]["attachment"]["body"][0]["details"]["datasetName"])))
+        if(len(filtered_result[0]["attachment"]["body"])>1):
+            display(HTML("<p>Filtered by: {}</p>".format(filtered_result[0]["attachment"]["body"][1]["details"]["text"])))
+        if(len(filtered_result)>1):
+            display(HTML("<p>{} Alternatives:</p>".format(len(filtered_result)-1)))
+            for r in filtered_result[1:]:
+                display(HTML("<p>     {} from the dataset: {} / {}</p>".format(self.extract_fields(r["attachment"]["body"][0]["details"]["columns"]), workspace, r["attachment"]["body"][0]["details"]["datasetName"])))
+
+        df = pd.DataFrame(data=filtered_result[0]["attachment"]["body"][0]["details"]["rows"], columns=filtered_result[0]["attachment"]["body"][0]["details"]["columns"])
         return df
 
     def load_agents(self):
